@@ -1,12 +1,13 @@
 #pragma once
 #include <halp/inline.hpp>
+#include <halp/modules.hpp>
 #include <halp/polyfill.hpp>
 #include <halp/static_string.hpp>
 #include <halp/value_types.hpp>
 
 #include <string_view>
 #include <type_traits>
-
+HALP_MODULE_EXPORT
 namespace halp
 {
 
