@@ -1,12 +1,14 @@
 #pragma once
 #include <halp/inline.hpp>
+#include <halp/modules.hpp>
 #include <halp/polyfill.hpp>
 #include <halp/static_string.hpp>
 #include <halp/value_types.hpp>
 
+#include <limits>
 #include <string_view>
 #include <type_traits>
-
+HALP_MODULE_EXPORT
 namespace halp
 {
 template <typename T>
@@ -23,6 +25,23 @@ inline constexpr auto default_range<int> = range{0., 127., 64.};
 template <typename T>
 inline constexpr auto default_irange = irange{0, 127, 64};
 
+// Range still constrained as many ui widgets bail out past some ~2^24 value
+template <typename T = long double>
+inline constexpr auto positive_range_min
+    = range{0., std::numeric_limits<int>::max() / 256., 0.};
+template <typename T = long double>
+inline constexpr auto positive_range_max
+    = range{0., std::numeric_limits<int>::max() / 256., 1.};
+
+template <typename T = long double>
+inline constexpr auto free_range_min = range{
+    std::numeric_limits<int>::lowest() / 256., std::numeric_limits<int>::max() / 256.,
+    0.};
+template <typename T = long double>
+inline constexpr auto free_range_max = range{
+    std::numeric_limits<int>::lowest() / 256., std::numeric_limits<int>::max() / 256.,
+    1.};
+
 template <typename T>
 struct init_range_t
 {
@@ -96,6 +115,7 @@ struct toggle_setup
 };
 
 inline constexpr auto default_toggle = toggle_setup{.init = false};
+inline constexpr auto default_on_toggle = toggle_setup{.init = false};
 
 /// XY position ///
 template <typename T, static_string lit, range setup>
