@@ -94,8 +94,16 @@ struct texture_output
 
   void create(int width, int height)
   {
-    storage.resize(
-        width * height * TextureType::bytes_per_pixel, boost::container::default_init);
+    if constexpr(requires { texture.bytes_per_pixel(); })
+    {
+      storage.resize(
+          width * height * texture.bytes_per_pixel(), boost::container::default_init);
+    }
+    else
+    {
+      storage.resize(
+          width * height * TextureType::bytes_per_pixel, boost::container::default_init);
+    }
     texture.width = width;
     texture.height = height;
     texture.changed = false;
@@ -110,10 +118,14 @@ struct texture_output
   }
 
   void set(int x, int y, rgba_color col) noexcept { texture.set(x, y, col); }
+  void set(int x, int y, rgb_color col) noexcept { texture.set(x, y, col); }
 
   TextureType texture;
 
   typename TextureType::uninitialized_bytes storage;
 };
 
+template <static_string lit>
+using rgb_texture_output = texture_output<lit, rgb_texture>;
+
 }
