@@ -9,6 +9,8 @@
 #define ASYNC_MQTT5_HPP
 
 #include <async_mqtt5/error.hpp>
+#include <async_mqtt5/logger.hpp>
+#include <async_mqtt5/logger_traits.hpp>
 #include <async_mqtt5/mqtt_client.hpp>
 #include <async_mqtt5/property_types.hpp>
 #include <async_mqtt5/reason_codes.hpp>
