@@ -22,22 +22,22 @@ public:
   explicit midi_in_kbd(input_configuration&& conf, kbd_input_configuration&& apiconf)
       : configuration{std::move(conf), std::move(apiconf)}
   {
-    configuration.set_input_scancode_callbacks(
-        [this](int v) { on_keypress(v); }, [this](int v) { on_keyrelease(v); });
   }
 
   ~midi_in_kbd() override { }
 
   libremidi::API get_current_api() const noexcept override { return libremidi::API::KEYBOARD; }
 
-  stdx::error open_port(const input_port&, std::string_view) override { return stdx::error{}; }
+  stdx::error open_port(const input_port&, std::string_view) override
+  {
+    configuration.set_input_scancode_callbacks(
+        [this](int v) { on_keypress(v); }, [this](int v) { on_keyrelease(v); });
 
-  stdx::error open_virtual_port(std::string_view) override { return stdx::error{}; }
+    return stdx::error{};
+  }
 
   stdx::error close_port() override { return stdx::error{}; }
 
-  stdx::error set_port_name(std::string_view) override { return stdx::error{}; }
-
   timestamp absolute_timestamp() const noexcept override
   {
     return std::chrono::steady_clock::now().time_since_epoch().count();
