@@ -250,7 +250,7 @@ public:
 
       messageCursor_ = BeginElement( messageCursor_ );
 
-      std::strncpy( messageCursor_, rhs.addressPattern.data(), rhs.addressPattern.size() );
+      std::memcpy(messageCursor_, rhs.addressPattern.data(), rhs.addressPattern.size());
 
       messageCursor_ += rhs.addressPattern.size();
       *messageCursor_++ = '\0';
