@@ -14,20 +14,23 @@
  * @section intro_sec Introduction
  *
  * Open source (under the MIT license) high-quality professional audio sample
- * rate converter (SRC) (resampling) library. Features routines for SRC, both
- * up- and downsampling, to/from any sample rate, including non-integer sample
- * rates: it can be also used for conversion to/from SACD sample rate and even
- * go beyond that. SRC routines were implemented in multi-platform C++ code,
- * and have a high level of optimality.
+ * rate converter (SRC) / resampler C++ library.  Features routines for SRC,
+ * both up- and downsampling, to/from any sample rate, including non-integer
+ * sample rates: it can be also used for conversion to/from SACD/DSD sample
+ * rates, and even go beyond that.  SRC routines were implemented in a
+ * multi-platform C++ code, and have a high level of optimality. Also suitable
+ * for fast general-purpose 1D time-series resampling / interpolation (with
+ * relaxed filter parameters).
  *
  * For more information, please visit
  * https://github.com/avaneev/r8brain-free-src
+ * E-mail: aleksey.vaneev@gmail.com or info@voxengo.com
  *
  * @section license License
  *
  * The MIT License (MIT)
  * 
- * r8brain-free-src Copyright (c) 2013-2022 Aleksey Vaneev
+ * r8brain-free-src Copyright (c) 2013-2023 Aleksey Vaneev
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -51,7 +54,7 @@
  * following way: "Sample rate converter designed by Aleksey Vaneev of
  * Voxengo"
  *
- * @version 5.7
+ * @version 6.5
  */
 
 #ifndef R8BBASE_INCLUDED
@@ -71,15 +74,19 @@
 
 #if defined( __SSE4_2__ ) || defined( __SSE4_1__ ) || \
 	defined( __SSSE3__ ) || defined( __SSE3__ ) || defined( __SSE2__ ) || \
-	defined( __x86_64__ ) || defined( _M_AMD64 ) || defined( _M_X64 ) || \
-	defined( __amd64 )
+	defined( __x86_64__ ) || defined( __amd64 ) || defined( _M_X64 ) || \
+	defined( _M_AMD64 ) || ( defined( _M_IX86_FP ) && _M_IX86_FP == 2 )
 
-	#include <immintrin.h>
+	#if defined( _MSC_VER )
+		#include <intrin.h>
+	#else // defined( _MSC_VER )
+		#include <emmintrin.h>
+	#endif // defined( _MSC_VER )
 
 	#define R8B_SSE2
 	#define R8B_SIMD_ISH
 
-#elif defined( __aarch64__ ) || defined( __arm64__ )
+#elif defined( __aarch64__ ) || defined( __arm64 )
 
 	#include <arm_neon.h>
 
@@ -89,7 +96,7 @@
 		#define R8B_SIMD_ISH // Shuffled interpolation is inefficient on M1.
 	#endif // !defined( __APPLE__ )
 
-#endif // ARM64
+#endif // AArch64
 
 /**
  * @brief The "r8brain-free-src" library namespace.
@@ -103,7 +110,7 @@ namespace r8b {
  * Macro defines r8brain-free-src version string.
  */
 
-#define R8B_VERSION "5.7"
+#define R8B_VERSION "6.5"
 
 /**
  * The macro equals to "pi" constant, fits 53-bit floating point mantissa.
@@ -135,7 +142,8 @@ namespace r8b {
 /**
  * A special macro that defines empty copy-constructor and copy operator with
  * the "private:" prefix. This macro should be used in classes that cannot be
- * copied in a standard C++ way.
+ * copied in a standard C++ way. It is also assumed that objects of such
+ * classes are non-relocatable.
  *
  * This macro does not need to be defined in classes derived from a class
  * where such macro was already used.
@@ -159,12 +167,11 @@ class CStdClassAllocator
 {
 public:
 	/**
-	 * @param n The size of the object, in bytes.
 	 * @param p Pointer to object's pre-allocated memory block.
 	 * @return Pointer to object.
 	 */
 
-	void* operator new( size_t, void* p )
+	void* operator new( const size_t, void* const p )
 	{
 		return( p );
 	}
@@ -174,7 +181,7 @@ public:
 	 * @return Pointer to the allocated memory block for the object.
 	 */
 
-	void* operator new( size_t n )
+	void* operator new( const size_t n )
 	{
 		return( :: malloc( n ));
 	}
@@ -184,7 +191,7 @@ public:
 	 * @return Pointer to the allocated memory block for the object.
 	 */
 
-	void* operator new[]( size_t n )
+	void* operator new[]( const size_t n )
 	{
 		return( :: malloc( n ));
 	}
@@ -195,7 +202,7 @@ public:
 	 * @param p Pointer to the allocated memory block for the object.
 	 */
 
-	void operator delete( void* p )
+	void operator delete( void* const p )
 	{
 		:: free( p );
 	}
@@ -206,7 +213,7 @@ public:
 	 * @param p Pointer to the allocated memory block for the object.
 	 */
 
-	void operator delete[]( void* p )
+	void operator delete[]( void* const p )
 	{
 		:: free( p );
 	}
@@ -225,7 +232,7 @@ public:
 	 * Function allocates memory block.
 	 *
 	 * @param Size The size of the block, in bytes.
-	 * @result The pointer to the allocated block.
+	 * @return The pointer to the allocated block.
 	 */
 
 	static void* allocmem( const size_t Size )
@@ -238,10 +245,10 @@ public:
 	 *
 	 * @param p Pointer to the allocated block, can be NULL.
 	 * @param Size The new size of the block, in bytes.
-	 * @result The pointer to the (re)allocated block.
+	 * @return The pointer to the (re)allocated block.
 	 */
 
-	static void* reallocmem( void* p, const size_t Size )
+	static void* reallocmem( void* const p, const size_t Size )
 	{
 		return( :: realloc( p, Size ));
 	}
@@ -252,7 +259,7 @@ public:
 	 * @param p Pointer to the allocated block, can be NULL.
 	 */
 
-	static void freemem( void* p )
+	static void freemem( void* const p )
 	{
 		:: free( p );
 	}
@@ -265,6 +272,7 @@ public:
  * @param ptr Pointer to align.
  * @param align Alignment, in bytes, power-of-2.
  * @tparam T Pointer's element type.
+ * @return Aligned pointer.
  */
 
 template< typename T >
@@ -387,16 +395,6 @@ public:
 		Data = NULL;
 	}
 
-	/**
-	 * @return Pointer to the first element of the allocated buffer, NULL if
-	 * not allocated.
-	 */
-
-	T* getPtr() const
-	{
-		return( Data );
-	}
-
 	/**
 	 * @return Pointer to the first element of the allocated buffer, NULL if
 	 * not allocated.
@@ -410,11 +408,8 @@ public:
 private:
 	static const size_t Alignment = 64; ///< Buffer address alignment, in
 		///< bytes.
-		///<
 	void* Data0; ///< Buffer pointer, original unaligned.
-		///<
 	T* Data; ///< Element buffer pointer, aligned.
-		///<
 };
 
 /**
@@ -428,7 +423,7 @@ private:
  * "CDSPFIRFilter*").
  */
 
-template< class T >
+template< typename T >
 class CPtrKeeper
 {
 	R8BNOCTOR( CPtrKeeper );
@@ -446,7 +441,7 @@ public:
 	 * @tparam T2 Object's pointer type.
 	 */
 
-	template< class T2 >
+	template< typename T2 >
 	CPtrKeeper( T2 const aObject )
 		: Object( aObject )
 	{
@@ -465,7 +460,7 @@ public:
 	 * @tparam T2 Object's pointer type.
 	 */
 
-	template< class T2 >
+	template< typename T2 >
 	void operator = ( T2 const aObject )
 	{
 		reset();
@@ -515,7 +510,6 @@ public:
 
 private:
 	T Object; ///< Pointer to keeped object.
-		///<
 };
 
 /**
@@ -536,7 +530,7 @@ public:
 	CSyncObject()
 	{
 		#if defined( _WIN32 )
-			InitializeCriticalSectionAndSpinCount( &CritSec, 4000 );
+			InitializeCriticalSectionAndSpinCount( &CritSec, 2000 );
 		#else // defined( _WIN32 )
 			pthread_mutexattr_t MutexAttrs;
 			pthread_mutexattr_init( &MutexAttrs );
@@ -587,10 +581,8 @@ private:
 	#if defined( _WIN32 )
 		CRITICAL_SECTION CritSec; ///< Standard Windows critical section
 			///< structure.
-			///<
 	#else // defined( _WIN32 )
 		pthread_mutex_t Mutex; ///< pthread.h mutex object.
-			///<
 	#endif // defined( _WIN32 )
 };
 
@@ -647,9 +639,8 @@ public:
 		}
 	}
 
-protected:
+private:
 	CSyncObject* SyncObj; ///< Sync object in use (can be NULL).
-		///<
 };
 
 /**
@@ -660,7 +651,7 @@ protected:
  * synchronization object thus blocking execution of other threads that also
  * use the same R8BSYNC( obj ) macro. The blocked section begins with the
  * R8BSYNC( obj ) macro and finishes at the end of the current C++ code block.
- * Multiple R8BSYNC() macros may be defined from within the same code block.
+ * Multiple R8BSYNC() macros can be defined within the same code block.
  *
  * @param SyncObject An object of the CSyncObject type that is used for
  * synchronization.
@@ -761,11 +752,8 @@ public:
 
 private:
 	double svalue1; ///< Current sine value.
-		///<
 	double svalue2; ///< Previous sine value.
-		///<
 	double sincr; ///< Sine value increment.
-		///<
 };
 
 /**
@@ -871,31 +859,22 @@ inline void calcFIRFilterResponse( const double* flt, int fltlen,
 }
 
 /**
- * Function calculates frequency response and group delay of the specified FIR
- * filter at the specified circular frequency. The group delay is calculated
- * by evaluating the filter's response at close side-band frequencies of "th".
+ * Function calculates group delay of the specified FIR filter at the
+ * specified circular frequency. The group delay is calculated by evaluating
+ * the filter's response at close side-band frequencies of "th".
  *
  * @param flt FIR filter's coefficients.
  * @param fltlen Number of coefficients (taps) in the filter.
  * @param th Circular frequency [0; pi].
- * @param[out] re Resulting real part of the complex frequency response.
- * @param[out] im Resulting imaginary part of the complex frequency response.
- * @param[out] gd Resulting group delay at the specified frequency, in
- * samples.
+ * @return Resulting group delay at the specified frequency, in samples.
  */
 
-inline void calcFIRFilterResponseAndGroupDelay( const double* const flt,
-	const int fltlen, const double th, double& re, double& im, double& gd )
+inline double calcFIRFilterGroupDelay( const double* const flt,
+	const int fltlen, const double th )
 {
-	// Calculate response at "th".
-
-	calcFIRFilterResponse( flt, fltlen, th, re, im );
-
-	// Calculate response at close sideband frequencies.
-
 	const int Count = 2;
 	const double thd2 = 1e-9;
-	double ths[ Count ] = { th - thd2, th + thd2 };
+	double ths[ Count ] = { th - thd2, th + thd2 }; // Side-band frequencies.
 
 	if( ths[ 0 ] < 0.0 )
 	{
@@ -932,7 +911,8 @@ inline void calcFIRFilterResponseAndGroupDelay( const double* const flt,
 	}
 
 	const double thd = ths[ 1 ] - ths[ 0 ];
-	gd = ( ph1[ 1 ] - ph1[ 0 ]) / thd;
+
+	return(( ph1[ 1 ] - ph1[ 0 ]) / thd );
 }
 
 /**
@@ -995,13 +975,13 @@ inline void calcSpline3p8Coeffs( double* const c, const double xm3,
 {
 	c[ 0 ] = x0;
 	c[ 1 ] = ( 61.0 * ( x1 - xm1 ) + 16.0 * ( xm2 - x2 ) +
-		3.0 * ( x3 - xm3 )) / 76.0;
+		3.0 * ( x3 - xm3 )) * 1.31578947368421052e-2;
 
 	c[ 2 ] = ( 106.0 * ( xm1 + x1 ) + 10.0 * x3 + 6.0 * xm3 - 3.0 * x4 -
-		29.0 * ( xm2 + x2 ) - 167.0 * x0 ) / 76.0;
+		29.0 * ( xm2 + x2 ) - 167.0 * x0 ) * 1.31578947368421052e-2;
 
 	c[ 3 ] = ( 91.0 * ( x0 - x1 ) + 45.0 * ( x2 - xm1 ) +
-		13.0 * ( xm2 - x3 ) + 3.0 * ( x4 - xm3 )) / 76.0;
+		13.0 * ( xm2 - x3 ) + 3.0 * ( x4 - xm3 )) * 1.31578947368421052e-2;
 }
 
 /**
@@ -1027,10 +1007,10 @@ inline void calcSpline2p8Coeffs( double* const c, const double xm3,
 {
 	c[ 0 ] = x0;
 	c[ 1 ] = ( 61.0 * ( x1 - xm1 ) + 16.0 * ( xm2 - x2 ) +
-		3.0 * ( x3 - xm3 )) / 76.0;
+		3.0 * ( x3 - xm3 )) * 1.31578947368421052e-2;
 
 	c[ 2 ] = ( 106.0 * ( xm1 + x1 ) + 10.0 * x3 + 6.0 * xm3 - 3.0 * x4 -
-		29.0 * ( xm2 + x2 ) - 167.0 * x0 ) / 76.0;
+		29.0 * ( xm2 + x2 ) - 167.0 * x0 ) * 1.31578947368421052e-2;
 }
 
 /**
@@ -1145,12 +1125,13 @@ inline double sqr( const double x )
 /**
  * @param v Input value.
  * @param p Power factor.
- * @return Returns pow() function's value with input value's sign check.
+ * @return Returns a precise, but generally approximate pow() function's value
+ * of absolute of input value.
  */
 
-inline double pows( const double v, const double p )
+inline double pow_a( const double v, const double p )
 {
-	return( v < 0.0 ? -pow( -v, p ) : pow( v, p ));
+	return( exp( p * log( fabs( v ) + 1e-300 )));
 }
 
 /**
