@@ -8,8 +8,6 @@
 #include <rapidfuzz/details/common.hpp>
 #include <rapidfuzz/distance/Indel.hpp>
 
-#include <type_traits>
-
 namespace rapidfuzz::fuzz {
 
 /**
@@ -42,12 +40,12 @@ namespace rapidfuzz::fuzz {
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
-template <typename InputIt1, typename InputIt2>
-double ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2, double score_cutoff = 0);
-
 template <typename Sentence1, typename Sentence2>
 double ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
 
+template <typename InputIt1, typename InputIt2>
+double ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2, double score_cutoff = 0);
+
 #ifdef RAPIDFUZZ_SIMD
 namespace experimental {
 template <int MaxLen>
@@ -108,10 +106,11 @@ struct CachedRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
     // private:
     CachedIndel<CharT1> cached_indel;
@@ -156,13 +155,13 @@ ScoreAlignment<double> partial_ratio_alignment(const Sentence1& s1, const Senten
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
+template <typename Sentence1, typename Sentence2>
+double partial_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
+
 template <typename InputIt1, typename InputIt2>
 double partial_ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2,
                      double score_cutoff = 0);
 
-template <typename Sentence1, typename Sentence2>
-double partial_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
-
 // todo add real implementation
 template <typename CharT1>
 struct CachedPartialRatio {
@@ -178,13 +177,14 @@ struct CachedPartialRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0.0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
 private:
-    std::basic_string<CharT1> s1;
+    std::vector<CharT1> s1;
     rapidfuzz::detail::CharSet<CharT1> s1_char_set;
     CachedRatio<CharT1> cached_ratio;
 };
@@ -221,13 +221,13 @@ CachedPartialRatio(InputIt1 first1, InputIt1 last1) -> CachedPartialRatio<iter_v
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
+template <typename Sentence1, typename Sentence2>
+double token_sort_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
+
 template <typename InputIt1, typename InputIt2>
 double token_sort_ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2,
                         double score_cutoff = 0);
 
-template <typename Sentence1, typename Sentence2>
-double token_sort_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
-
 #ifdef RAPIDFUZZ_SIMD
 namespace experimental {
 template <int MaxLen>
@@ -287,13 +287,14 @@ struct CachedTokenSortRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
 private:
-    std::basic_string<CharT1> s1_sorted;
+    std::vector<CharT1> s1_sorted;
     CachedRatio<CharT1> cached_ratio;
 };
 
@@ -323,13 +324,13 @@ CachedTokenSortRatio(InputIt1 first1, InputIt1 last1) -> CachedTokenSortRatio<it
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
+template <typename Sentence1, typename Sentence2>
+double partial_token_sort_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
+
 template <typename InputIt1, typename InputIt2>
 double partial_token_sort_ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2,
                                 double score_cutoff = 0);
 
-template <typename Sentence1, typename Sentence2>
-double partial_token_sort_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
-
 // TODO documentation
 template <typename CharT1>
 struct CachedPartialTokenSortRatio {
@@ -344,13 +345,14 @@ struct CachedPartialTokenSortRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
 private:
-    std::basic_string<CharT1> s1_sorted;
+    std::vector<CharT1> s1_sorted;
     CachedPartialRatio<CharT1> cached_partial_ratio;
 };
 
@@ -390,13 +392,13 @@ CachedPartialTokenSortRatio(InputIt1 first1, InputIt1 last1)
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
+template <typename Sentence1, typename Sentence2>
+double token_set_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
+
 template <typename InputIt1, typename InputIt2>
 double token_set_ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2,
                        double score_cutoff = 0);
 
-template <typename Sentence1, typename Sentence2>
-double token_set_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
-
 // TODO documentation
 template <typename CharT1>
 struct CachedTokenSetRatio {
@@ -411,14 +413,15 @@ struct CachedTokenSetRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
 private:
-    std::basic_string<CharT1> s1;
-    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
+    std::vector<CharT1> s1;
+    detail::SplittedSentenceView<typename std::vector<CharT1>::iterator> tokens_s1;
 };
 
 template <typename Sentence1>
@@ -446,13 +449,13 @@ CachedTokenSetRatio(InputIt1 first1, InputIt1 last1) -> CachedTokenSetRatio<iter
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
+template <typename Sentence1, typename Sentence2>
+double partial_token_set_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
+
 template <typename InputIt1, typename InputIt2>
 double partial_token_set_ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2,
                                double score_cutoff = 0);
 
-template <typename Sentence1, typename Sentence2>
-double partial_token_set_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
-
 // TODO documentation
 template <typename CharT1>
 struct CachedPartialTokenSetRatio {
@@ -467,14 +470,15 @@ struct CachedPartialTokenSetRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
 private:
-    std::basic_string<CharT1> s1;
-    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
+    std::vector<CharT1> s1;
+    detail::SplittedSentenceView<typename std::vector<CharT1>::iterator> tokens_s1;
 };
 
 template <typename Sentence1>
@@ -503,12 +507,12 @@ CachedPartialTokenSetRatio(InputIt1 first1, InputIt1 last1)
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
-template <typename InputIt1, typename InputIt2>
-double token_ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2, double score_cutoff = 0);
-
 template <typename Sentence1, typename Sentence2>
 double token_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
 
+template <typename InputIt1, typename InputIt2>
+double token_ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2, double score_cutoff = 0);
+
 // todo add real implementation
 template <typename CharT1>
 struct CachedTokenRatio {
@@ -526,15 +530,16 @@ struct CachedTokenRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
 private:
-    std::basic_string<CharT1> s1;
-    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> s1_tokens;
-    std::basic_string<CharT1> s1_sorted;
+    std::vector<CharT1> s1;
+    detail::SplittedSentenceView<typename std::vector<CharT1>::iterator> s1_tokens;
+    std::vector<CharT1> s1_sorted;
     CachedRatio<CharT1> cached_ratio_s1_sorted;
 };
 
@@ -564,13 +569,13 @@ CachedTokenRatio(InputIt1 first1, InputIt1 last1) -> CachedTokenRatio<iter_value
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
+template <typename Sentence1, typename Sentence2>
+double partial_token_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
+
 template <typename InputIt1, typename InputIt2>
 double partial_token_ratio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2,
                            double score_cutoff = 0);
 
-template <typename Sentence1, typename Sentence2>
-double partial_token_ratio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
-
 // todo add real implementation
 template <typename CharT1>
 struct CachedPartialTokenRatio {
@@ -587,15 +592,16 @@ struct CachedPartialTokenRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
 private:
-    std::basic_string<CharT1> s1;
-    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
-    std::basic_string<CharT1> s1_sorted;
+    std::vector<CharT1> s1;
+    detail::SplittedSentenceView<typename std::vector<CharT1>::iterator> tokens_s1;
+    std::vector<CharT1> s1_sorted;
 };
 
 template <typename Sentence1>
@@ -625,12 +631,12 @@ CachedPartialTokenRatio(InputIt1 first1, InputIt1 last1) -> CachedPartialTokenRa
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
-template <typename InputIt1, typename InputIt2>
-double WRatio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2, double score_cutoff = 0);
-
 template <typename Sentence1, typename Sentence2>
 double WRatio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
 
+template <typename InputIt1, typename InputIt2>
+double WRatio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2, double score_cutoff = 0);
+
 // todo add real implementation
 template <typename CharT1>
 struct CachedWRatio {
@@ -642,18 +648,19 @@ struct CachedWRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
 private:
     // todo somehow implement this using other ratios with creating PatternMatchVector
     // multiple times
-    std::basic_string<CharT1> s1;
+    std::vector<CharT1> s1;
     CachedPartialRatio<CharT1> cached_partial_ratio;
-    detail::SplittedSentenceView<typename std::basic_string<CharT1>::iterator> tokens_s1;
-    std::basic_string<CharT1> s1_sorted;
+    detail::SplittedSentenceView<typename std::vector<CharT1>::iterator> tokens_s1;
+    std::vector<CharT1> s1_sorted;
     rapidfuzz::detail::BlockPatternMatchVector blockmap_s1_sorted;
 };
 
@@ -684,12 +691,12 @@ CachedWRatio(InputIt1 first1, InputIt1 last1) -> CachedWRatio<iter_value_t<Input
  *
  * @return returns the ratio between s1 and s2 or 0 when ratio < score_cutoff
  */
-template <typename InputIt1, typename InputIt2>
-double QRatio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2, double score_cutoff = 0);
-
 template <typename Sentence1, typename Sentence2>
 double QRatio(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0);
 
+template <typename InputIt1, typename InputIt2>
+double QRatio(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2, double score_cutoff = 0);
+
 #ifdef RAPIDFUZZ_SIMD
 namespace experimental {
 template <int MaxLen>
@@ -758,13 +765,14 @@ struct CachedQRatio {
     {}
 
     template <typename InputIt2>
-    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0) const;
+    double similarity(InputIt2 first2, InputIt2 last2, double score_cutoff = 0.0,
+                      double score_hint = 0.0) const;
 
     template <typename Sentence2>
-    double similarity(const Sentence2& s2, double score_cutoff = 0) const;
+    double similarity(const Sentence2& s2, double score_cutoff = 0.0, double score_hint = 0.0) const;
 
 private:
-    std::basic_string<CharT1> s1;
+    std::vector<CharT1> s1;
     CachedRatio<CharT1> cached_ratio;
 };
 
@@ -778,4 +786,4 @@ CachedQRatio(InputIt1 first1, InputIt1 last1) -> CachedQRatio<iter_value_t<Input
 
 } // namespace rapidfuzz::fuzz
 
-#include <rapidfuzz/fuzz.impl>
+#include <rapidfuzz/fuzz_impl.hpp>
