@@ -4,12 +4,12 @@
 #include <ossia/network/base/message_origin_identifier.hpp>
 #include <ossia/network/common/network_logger.hpp>
 
-#include <tcb/span.hpp>
-
 #include <nano_signal_slot.hpp>
 
+#include <atomic>
 #include <future>
 #include <memory>
+#include <span>
 #include <vector>
 
 namespace ossia
@@ -96,8 +96,8 @@ public:
    * @brief Send many values in one go if the protocol supports it
    */
   virtual bool push_bundle(const std::vector<const ossia::net::parameter_base*>&);
-  virtual bool push_bundle(tcb::span<ossia::bundle_element>);
-  virtual bool push_bundle_bounded(tcb::span<ossia::bundle_element>);
+  virtual bool push_bundle(std::span<ossia::bundle_element>);
+  virtual bool push_bundle_bounded(std::span<ossia::bundle_element>);
 
   /**
    * @brief Send a value to the network.
