@@ -1,6 +1,5 @@
 #include "coap_client_protocol.hpp"
 
-
 #include <ossia/network/base/node.hpp>
 #include <ossia/network/base/node_functions.hpp>
 #include <ossia/network/base/parameter.hpp>
@@ -14,6 +13,7 @@
 #include <boost/unordered/concurrent_flat_map.hpp>
 
 #include <coap3/coap.h>
+
 namespace ossia::net
 {
 struct coap_destination
@@ -101,7 +101,7 @@ struct coap_client
 
 private:
   boost::unordered::concurrent_flat_map<
-      coap_session_t*, std::shared_ptr<coap_session>, std::hash<coap_session_t*>>
+      coap_session_t*, std::shared_ptr<coap_session>, ossia::unknown_pointer_hash<800>>
       in_flight;
 };
 
