@@ -51,7 +51,7 @@ public:
       struct
   {
     halp::fixed_texture_input<"In"> image;
-    ModelPort model;
+    ModelPort<"Model"> model;
     halp::xy_spinboxes_i32<"Model input resolution", halp::range{1, 2048, 256}>
         resolution;
     halp::hslider_f32<"Minimum confidence", halp::range{0., 1., 0.5}>
