@@ -15,7 +15,7 @@ class SCORE_LIB_BASE_EXPORT QGraphicsToggle final
     , public QGraphicsItem
 {
   W_OBJECT(QGraphicsToggle)
-  Q_INTERFACES(QGraphicsItem)
+  SCORE_GRAPHICS_ITEM_TYPE(240)
   QRectF m_rect{defaultToggleSize};
 
   QString m_textToggled{};
