@@ -1,9 +1,18 @@
 #pragma once
+#include <QCheckBox>
 #include <QComboBox>
 #include <QSpinBox>
 
 struct SignalUtils
 {
+  static constexpr auto QCheckBox_checkStateChanged()
+  {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    return &QCheckBox::checkStateChanged;
+#else
+    return &QCheckBox::stateChanged;
+#endif
+  }
   static constexpr auto QSpinBox_valueChanged_int()
   {
     return static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged);
