@@ -2,8 +2,11 @@
 // it. PVS-Studio Static Code Analyzer for C, C++ and C#: http://www.viva64.com
 #include "ProtocolFactoryInterface.hpp"
 
+#include <QUrl>
+
 #include <wobjectimpl.h>
 W_OBJECT_IMPL(Device::DeviceEnumerator)
+
 namespace Device
 {
 ProtocolFactory::~ProtocolFactory() = default;
@@ -18,12 +21,23 @@ int ProtocolFactory::visualPriority() const noexcept
   return 0;
 }
 
+QUrl ProtocolFactory::manual() const noexcept
+{
+  return {};
+}
+
 DeviceEnumerators
 ProtocolFactory::getEnumerators(const score::DocumentContext& ctx) const
 {
   return {};
 }
 
+bool ProtocolFactory::checkResourcesAvailable(
+    const Device::DeviceSettings& a, const DeviceResourceMap&) const noexcept
+{
+  return true;
+}
+
 DeviceEnumerator::~DeviceEnumerator() { }
 
 }
