@@ -4,6 +4,8 @@
 
 #include <score/plugins/application/GUIApplicationPlugin.hpp>
 
+#include <Process/Layer/LayerContextMenu.hpp>
+
 namespace Process
 {
 
@@ -14,7 +16,6 @@ class SCORE_LIB_PROCESS_EXPORT ApplicationPlugin
   W_OBJECT(ApplicationPlugin)
 public:
   explicit ApplicationPlugin(const score::ApplicationContext& ctx);
-
   ~ApplicationPlugin();
 
   void savePreset(const Process::ProcessModel* proc)
@@ -22,7 +23,18 @@ public:
 
   void addPreset(Process::Preset&& p);
 
+  Process::LayerContextMenuManager& layerContextMenuRegistrar()
+  {
+    return m_layerCtxMenuManager;
+  }
+
+  const Process::LayerContextMenuManager& layerContextMenuRegistrar() const
+  {
+    return m_layerCtxMenuManager;
+  }
+
   std::vector<Process::Preset> presets;
+  Process::LayerContextMenuManager m_layerCtxMenuManager;
 };
 
 }
