@@ -2,6 +2,8 @@
 #include <Process/Dataflow/Cable.hpp>
 #include <Process/Dataflow/Port.hpp>
 
+#include <score/widgets/MimeData.hpp>
+
 #include <ossia/detail/ptr_set.hpp>
 
 #include <QGraphicsItem>
@@ -16,9 +18,18 @@ class CableItem;
 namespace Process
 {
 struct Context;
+struct Style;
 }
 namespace Dataflow
 {
+enum CableDisplayMode : uint8_t
+{
+  None,
+  Partial_P1,
+  Partial_P2,
+  Full
+};
+
 class PortItem;
 class SCORE_LIB_PROCESS_EXPORT CableItem final
     : public QObject
@@ -45,9 +56,14 @@ public:
   PortItem* target() const noexcept;
   void setSource(PortItem* p);
   void setTarget(PortItem* p);
+  void resetDrop()
+  {
+    m_dropping = false;
+    update();
+  }
 
-public:
-  void removeRequested() E_SIGNAL(SCORE_LIB_PROCESS_EXPORT, removeRequested)
+  void dropReceived(const QPointF& pos, const QMimeData& arg_2)
+      E_SIGNAL(SCORE_LIB_PROCESS_EXPORT, dropReceived, pos, arg_2)
 
 private:
   QRectF boundingRect() const override;
@@ -59,15 +75,21 @@ private:
   void mousePressEvent(QGraphicsSceneMouseEvent* event) override;
   void mouseMoveEvent(QGraphicsSceneMouseEvent* event) override;
   void mouseReleaseEvent(QGraphicsSceneMouseEvent* event) override;
+  void dragEnterEvent(QGraphicsSceneDragDropEvent* event) override;
+  void dragLeaveEvent(QGraphicsSceneDragDropEvent* event) override;
+  void dropEvent(QGraphicsSceneDragDropEvent* event) override;
   void keyPressEvent(QKeyEvent* event) override;
   void keyReleaseEvent(QKeyEvent* event) override;
 
+  void setPen(QPainter& painter, const Process::Style& style);
   void updateStroke() const;
   const Process::Cable& m_cable;
   const Process::Context& m_context;
   QPointer<PortItem> m_p1, m_p2;
   QPainterPath m_path;
   mutable QPainterPath m_stroke;
-  Process::PortType m_type{};
+  Process::PortType m_type : 4 {};
+  bool m_dropping : 1 {};
+  CableDisplayMode m_mode : 2 {CableDisplayMode::None};
 };
 }
