@@ -77,8 +77,8 @@ struct FloatControl
   {
     using namespace Process;
     if constexpr(
-        std::is_same_v<score::QGraphicsKnob, ControlUI>
-        || std::is_same_v<score::QGraphicsLogKnob, ControlUI>)
+        std::is_base_of_v<score::QGraphicsKnob, ControlUI>
+        || std::is_base_of_v<score::QGraphicsLogKnob, ControlUI>)
     {
       return DefaultControlLayouts::knob();
     }
@@ -567,6 +567,25 @@ struct TimeChooser
     return nullptr;
   }
 
+  template <typename T>
+  static ossia::vec2f mapTimeFromUI(T& normalizer, ossia::vec2f in)
+  {
+    if(in[1] < 0.0001f)
+    {
+      in[0] = normalizer.from01(in[0]);
+    }
+    return in;
+  }
+  template <typename T>
+  static ossia::vec2f mapTimeToUI(T& normalizer, ossia::vec2f in)
+  {
+    if(in[1] < 0.0001f)
+    {
+      in[0] = normalizer.to01(in[0]);
+    }
+    return in;
+  }
+
   template <typename T, typename Control_T>
   static auto make_item(
       const T& slider, Control_T& inlet, const score::DocumentContext& ctx,
@@ -574,34 +593,42 @@ struct TimeChooser
   {
     auto sl = new score::QGraphicsTimeChooser{nullptr};
     initWidgetProperties(inlet, *sl);
-    // bindFloatDomain(slider, inlet, *sl);
-    sl->setValue(ossia::convert<ossia::vec2f>(inlet.value()));
+    bindFloatDomain(slider, inlet, sl->knob);
+
+    ConcreteNormalizer<LinearNormalizer, T> norm{slider};
+
+    sl->setValue(mapTimeToUI(norm, ossia::convert<ossia::vec2f>(inlet.value())));
 
     QObject::connect(
-        sl, &score::QGraphicsTimeChooser::sliderMoved, context, [sl, &inlet, &ctx] {
-          sl->knob.moving = true;
-          sl->combo.moving = true;
-          ctx.dispatcher.submit<SetControlValue<Control_T>>(inlet, sl->value());
-        });
+        sl, &score::QGraphicsTimeChooser::sliderMoved, context,
+        [norm, sl, &inlet, &ctx] {
+      sl->knob.moving = true;
+      sl->combo.moving = true;
+      ctx.dispatcher.submit<SetControlValue<Control_T>>(
+          inlet, mapTimeFromUI(norm, ossia::convert<ossia::vec2f>(sl->value())));
+    });
     QObject::connect(
-        sl, &score::QGraphicsTimeChooser::sliderReleased, context, [sl, &inlet, &ctx] {
-          ctx.dispatcher.submit<SetControlValue<Control_T>>(inlet, sl->value());
-          ctx.dispatcher.commit();
-          sl->knob.moving = false;
-          sl->combo.moving = false;
-        });
+        sl, &score::QGraphicsTimeChooser::sliderReleased, context,
+        [norm, sl, &inlet, &ctx] {
+      ctx.dispatcher.submit<SetControlValue<Control_T>>(
+          inlet, mapTimeFromUI(norm, ossia::convert<ossia::vec2f>(sl->value())));
+      ctx.dispatcher.commit();
+      sl->knob.moving = false;
+      sl->combo.moving = false;
+    });
 
     QObject::connect(
-        &inlet, &Control_T::valueChanged, sl, [sl](const ossia::value& val) {
-          if(!sl->knob.moving && !sl->combo.moving)
-          {
-            sl->setValue(ossia::convert<ossia::vec2f>(val));
-          }
-        });
+        &inlet, &Control_T::valueChanged, sl, [norm, sl](const ossia::value& val) {
+      if(!sl->knob.moving && !sl->combo.moving)
+      {
+        sl->setValue(mapTimeToUI(norm, ossia::convert<ossia::vec2f>(val)));
+      }
+    });
     QObject::connect(
-        &inlet, &Control_T::executionValueChanged, sl, [sl](const ossia::value& val) {
-          sl->setExecutionValue(ossia::convert<ossia::vec2f>(val));
-        });
+        &inlet, &Control_T::executionValueChanged, sl,
+        [norm, sl](const ossia::value& val) {
+      sl->setExecutionValue(mapTimeToUI(norm, ossia::convert<ossia::vec2f>(val)));
+    });
     QObject::connect(
         &inlet, &Control_T::executionReset, sl,
         &score::QGraphicsTimeChooser::resetExecution);
@@ -1054,7 +1081,11 @@ struct FileChooser
       if(str != bt->text())
       {
         if(!str.isEmpty())
-          bt->setText(str.split("/").back());
+        {
+          auto no_colon = str.split(":").back();
+          auto no_slash = no_colon.split("/").back();
+          bt->setText(no_slash);
+        }
         else
           bt->setText("Choose a file...");
       }
