@@ -127,13 +127,13 @@ public:
       : Execution::ProcessComponent_T<ProcessModel<Node>, ossia::node_process>{
           element, ctx, "Executor::ProcessModel<Info>", p}
   {
-#if SCORE_PLUGIN_GFX
     if constexpr(is_gpu<Node>)
     {
+#if SCORE_PLUGIN_GFX
       setup_gpu(element, ctx, p);
+#endif
     }
     else
-#endif
     {
       setup_cpu(element, ctx, p);
     }
@@ -199,7 +199,7 @@ public:
   {
 #if SCORE_PLUGIN_GFX
     // FIXME net context for gpu node ?
-    const auto id
+    const int64_t id
         = std::hash<ObjectPath>{}(Path<Process::ProcessModel>{element}.unsafePath());
 
     auto& gfx_exec = ctx.doc.plugin<Gfx::DocumentPlugin>().exec;
@@ -315,7 +315,7 @@ public:
       return;
 
     // Re-run setup_inlets ?
-    this->in_exec([dp = this->process().dynamic_ports, node = n] {
+    in_exec([dp = this->process().dynamic_ports, node = n] {
       node->dynamic_ports = dp;
       node->root_inputs().clear();
       node->root_outputs().clear();
@@ -392,7 +392,7 @@ public:
     {
       // Update the value in the UI
       std::weak_ptr<safe_node<Node>> weak_node = ptr;
-      update_control_value_in_ui<Node> timer_action{weak_node, element};
+      update_control_value_in_ui<Node> timer_action{weak_node, &element};
       timer_action();
 
       con(ctx.doc.coarseUpdateTimer, &QTimer::timeout, this,
@@ -444,11 +444,12 @@ public:
     // Custom UI messages to engine
     if constexpr(avnd::has_gui_to_processor_bus<Node>)
     {
-      element.from_ui = [p = QPointer{this}, &eff](QByteArray b) {
-        if(!p)
+      element.from_ui = [qex_ptr = weak_exec, &eff](QByteArray b) {
+        auto qex = qex_ptr.lock();
+        if(!qex)
           return;
 
-        p->in_exec([mess = std::move(b), &eff]() mutable {
+        qex->enqueue([mess = std::move(b), &eff]() mutable {
           using refl = avnd::function_reflection<&Node::process_message>;
           static_assert(refl::count <= 1);
 
@@ -471,29 +472,48 @@ public:
 
     if constexpr(avnd::has_processor_to_gui_bus<Node>)
     {
-      eff.send_message = [self = QPointer{this}]<typename T>(T&& b) mutable {
-        if(!self)
-          return;
-        if constexpr(
-            sizeof(QPointer<QObject>) + sizeof(b)
-            < Execution::ExecutionCommand::max_storage)
-        {
-          self->in_edit(
-              [proc = QPointer{&self->process()}, bb = std::move(b)]() mutable {
+      if constexpr(requires { eff.send_message = [](auto&&) { }; })
+      {
+        eff.send_message = [proc = QPointer{&this->process()},
+                            qed_ptr = weak_edit]<typename T>(T&& b) mutable {
+          auto qed = qed_ptr.lock();
+          if(!qed)
+            return;
+          if constexpr(
+              sizeof(QPointer<QObject>) + sizeof(b)
+              < Execution::ExecutionCommand::max_storage)
+          {
+            qed->enqueue([proc, bb = std::move(b)]() mutable {
+              if(proc && proc->to_ui)
+                MessageBusSender{proc->to_ui}(std::move(bb));
+            });
+          }
+          else
+          {
+            qed->enqueue(
+                [proc, bb = std::make_unique<std::decay_t<T>>(std::move(b))]() mutable {
+              if(proc && proc->to_ui)
+                MessageBusSender{proc->to_ui}(*std::move(bb));
+            });
+          }
+        };
+      }
+      else if constexpr(requires { eff.send_message = []() { }; })
+      {
+        eff.send_message
+            = [proc = QPointer{&this->process()}, qed_ptr = weak_edit]() mutable {
+          if(!proc)
+            return;
+          auto qed = qed_ptr.lock();
+          if(!qed)
+            return;
+
+          qed->enqueue([proc]() mutable {
             if(proc && proc->to_ui)
-              MessageBusSender{proc->to_ui}(std::move(bb));
+              MessageBusSender{proc->to_ui}();
           });
-        }
-        else
-        {
-          self->in_edit(
-              [proc = QPointer{&self->process()},
-               bb = std::make_unique<std::decay_t<T>>(std::move(b))]() mutable {
-            if(proc && proc->to_ui)
-              MessageBusSender{proc->to_ui}(*std::move(bb));
-          });
-        }
-      };
+        };
+      }
     }
   }
 
