@@ -3,7 +3,6 @@
 #include <Process/Process.hpp>
 #include <Process/ProcessFactory.hpp>
 
-#include <Crousti/Attributes.hpp>
 #include <Crousti/Concepts.hpp>
 #include <Crousti/MessageBus.hpp>
 #include <Crousti/Metadata.hpp>
@@ -71,6 +70,14 @@ struct MessageBusWrapperFromUi<Info>
   std::function<void(QByteArray)> from_ui = dummy_ui_callback{};
 };
 
+inline void hideAllInlets(Process::ProcessModel& proc)
+{
+  for(auto& p : proc.inlets())
+    p->hidden = true;
+  for(auto& p : proc.outlets())
+    p->hidden = true;
+}
+
 template <typename Info>
 class ProcessModel final
     : public Process::ProcessModel
@@ -171,7 +178,8 @@ private:
     if(std::ssize(m_inlets) != expected_input_ports()
        || std::ssize(m_outlets) != expected_output_ports())
     {
-      qDebug() << "Warning : process does not match spec: I " << m_inlets.size()
+      qDebug() << typeid(Info).name() << this->metadata().getName()
+               << ": WARNING : process does not match spec: I " << m_inlets.size()
                << "but expected: " << expected_input_ports() << " ; O "
                << m_outlets.size() << "but expected: " << expected_output_ports();
 
@@ -223,6 +231,14 @@ private:
           SCORE_ASSERT(controller_inlets.size() == 1);
           auto inlet = qobject_cast<Process::ControlInlet*>(controller_inlets[0]);
           inlet->noValueChangeOnMove = true;
+
+          if constexpr(!requires { F::on_controller_setup(); })
+          {
+            oscr::from_ossia_value(inlet->value(), field.value);
+            if_possible(field.update(obj));
+            F::on_controller_interaction()(obj, field.value);
+          }
+
           connect(
               inlet, &Process::ControlInlet::valueChanged,
               [this, &field](const ossia::value& val) {
@@ -465,6 +481,10 @@ private:
       if constexpr(!avnd::dynamic_ports_port<P>)
         outlets(port, idx);
     });
+
+    if(!requires { Info::ossia_show_ports_by_default; })
+      if constexpr(oscr::has_ossia_layer<Info>)
+        hideAllInlets(*this);
   }
 
 public:
@@ -833,11 +853,11 @@ struct TSerializer<JSONObject, oscr::ProcessModel<Info>>
     {
       if(auto val = s.obj.tryGet("DynamicInlets"))
       {
-        ossia::string_map<int> indices;
+        static ossia::string_map<int> indices;
+        indices.clear();
         indices <<= *val;
         avnd::dynamic_ports_input_introspection<Info>::for_all(
-            [&obj, &indices]<std::size_t Idx, typename P>(
-                avnd::field_reflection<Idx, P> field) {
+            [&obj]<std::size_t Idx, typename P>(avnd::field_reflection<Idx, P> field) {
           if constexpr(avnd::dynamic_ports_port<P>)
             obj.dynamic_ports.num_in_ports(avnd::field_index<Idx>{})
                 = indices[std::string(avnd::get_c_identifier<P>())];
@@ -848,11 +868,11 @@ struct TSerializer<JSONObject, oscr::ProcessModel<Info>>
     {
       if(auto val = s.obj.tryGet("DynamicOutlets"))
       {
-        ossia::string_map<int> indices;
+        static ossia::string_map<int> indices;
+        indices.clear();
         indices <<= *val;
         avnd::dynamic_ports_output_introspection<Info>::for_all(
-            [&obj, &indices]<std::size_t Idx, typename P>(
-                avnd::field_reflection<Idx, P> field) {
+            [&obj]<std::size_t Idx, typename P>(avnd::field_reflection<Idx, P> field) {
           if constexpr(avnd::dynamic_ports_port<P>)
             obj.dynamic_ports.num_out_ports(avnd::field_index<Idx>{})
                 = indices[std::string(avnd::get_c_identifier<P>())];
