@@ -6,6 +6,8 @@
 #include <score/command/Command.hpp>
 #include <score/model/path/Path.hpp>
 
+#include <score_plugin_deviceexplorer_export.h>
+
 struct DataStreamInput;
 struct DataStreamOutput;
 
@@ -15,7 +17,7 @@ class DeviceDocumentPlugin;
 namespace Command
 {
 // TODO split this command.
-class Remove final : public score::Command
+class SCORE_PLUGIN_DEVICEEXPLORER_EXPORT Remove final : public score::Command
 {
   SCORE_COMMAND_DECL(
       DeviceExplorerCommandFactoryName(), Remove, "Remove an Explorer node")
