@@ -13,17 +13,13 @@ struct ProcessUBO
   float time{};
   float timeDelta{};
   float progress{};
+  float sampleRate{};
 
   int32_t passIndex{};
   int32_t frameIndex{};
 
-  float padding0[1];
   float renderSize[2]{2048, 2048};
   float date[4]{0.f, 0.f, 0.f, 0.f};
-  float mouse[4]{0.5f, 0.5f, 0.5f, 0.5f};
-  float channelTime[4]{0.5f, 0.5f, 0.5f, 0.5f};
-
-  float sampleRate{};
 };
 
 /**
