@@ -45,11 +45,30 @@ struct isf_input_size_vis
     sz += 4 * 4;
   }
 
-  void operator()(const isf::image_input&) noexcept { (*this)(isf::color_input{}); }
+  void operator()(const isf::image_input&) noexcept { }
 
-  void operator()(const isf::audio_input&) noexcept { (*this)(isf::color_input{}); }
+  void operator()(const isf::audio_input&) noexcept { }
+  void operator()(const isf::audioFFT_input&) noexcept { }
+  void operator()(const isf::audioHist_input&) noexcept { }
 
-  void operator()(const isf::audioFFT_input&) noexcept { (*this)(isf::color_input{}); }
+  // CSF-specific input handlers
+  void operator()(const isf::storage_input& in) noexcept
+  {
+    if(in.access.contains("write"))
+    {
+      (*this)(isf::long_input{});
+    }
+  }
+
+  void operator()(const isf::texture_input in) noexcept { }
+
+  void operator()(const isf::csf_image_input& in) noexcept
+  {
+    if(in.access.contains("write"))
+    {
+      (*this)(isf::point2d_input{});
+      (*this)(isf::long_input{});
+    }
+  }
 };
-
 }
