@@ -40,8 +40,8 @@
 
 namespace score::gfx
 {
-static std::shared_ptr<RenderState>
-createRenderState(QWindow& window, GraphicsApi graphicsApi)
+std::shared_ptr<RenderState>
+createRenderState(GraphicsApi graphicsApi, QSize sz, QWindow* window)
 {
   auto st = std::make_shared<RenderState>();
   RenderState& state = *st;
@@ -60,16 +60,19 @@ createRenderState(QWindow& window, GraphicsApi graphicsApi)
   {
     state.surface = QRhiGles2InitParams::newFallbackSurface();
     QRhiGles2InitParams params;
-    params.format = window.format();
+    if(window)
+    {
+      params.format = window->format();
+      params.window = window;
+    }
     params.fallbackSurface = state.surface;
-    params.window = &window;
 
     score::GLCapabilities caps;
     caps.setupFormat(params.format);
     params.format.setSamples(state.samples);
     state.version = caps.qShaderVersion;
     state.rhi = QRhi::create(QRhi::OpenGLES2, &params, flags);
-    state.renderSize = window.size();
+    state.renderSize = sz;
     return st;
   }
 #endif
@@ -78,12 +81,19 @@ createRenderState(QWindow& window, GraphicsApi graphicsApi)
   if(graphicsApi == Vulkan)
   {
     QRhiVulkanInitParams params;
-    params.inst = window.vulkanInstance();
-    params.window = &window;
+    if(window)
+    {
+      params.inst = window->vulkanInstance();
+      params.window = window;
+    }
+    else
+    {
+      params.inst = score::gfx::staticVulkanInstance();
+    }
     // Note: QShaderVersion still hardcoded to 100 in qrhvulkan.cpp as of qt 6.9
     state.version = QShaderVersion(100);
     state.rhi = QRhi::create(QRhi::Vulkan, &params, flags);
-    state.renderSize = window.size();
+    state.renderSize = sz;
     return st;
   }
 #endif
@@ -102,7 +112,7 @@ createRenderState(QWindow& window, GraphicsApi graphicsApi)
     // }
     state.version = QShaderVersion(50);
     state.rhi = QRhi::create(QRhi::D3D11, &params, flags);
-    state.renderSize = window.size();
+    state.renderSize = sz;
     return st;
   }
 #if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
@@ -119,7 +129,7 @@ createRenderState(QWindow& window, GraphicsApi graphicsApi)
     // }
     state.version = QShaderVersion(50);
     state.rhi = QRhi::create(QRhi::D3D12, &params, flags);
-    state.renderSize = window.size();
+    state.renderSize = sz;
     return st;
   }
 #endif
@@ -131,7 +141,7 @@ createRenderState(QWindow& window, GraphicsApi graphicsApi)
     QRhiMetalInitParams params;
     state.version = QShaderVersion(12);
     state.rhi = QRhi::create(QRhi::Metal, &params, flags);
-    state.renderSize = window.size();
+    state.renderSize = sz;
     return st;
   }
 #endif
@@ -143,7 +153,7 @@ createRenderState(QWindow& window, GraphicsApi graphicsApi)
     QRhiNullInitParams params;
     state.version = QShaderVersion(120);
     state.rhi = QRhi::create(QRhi::Null, &params, flags);
-    state.renderSize = window.size();
+    state.renderSize = sz;
     state.api = GraphicsApi::Null;
     return st;
   }
@@ -151,6 +161,12 @@ createRenderState(QWindow& window, GraphicsApi graphicsApi)
   return st;
 }
 
+static std::shared_ptr<RenderState>
+createRenderState(QWindow& window, GraphicsApi graphicsApi)
+{
+  return createRenderState(graphicsApi, window.size(), &window);
+}
+
 ScreenNode::ScreenNode(bool embedded, bool fullScreen)
     : OutputNode{}
     , m_embedded{embedded}
@@ -366,6 +382,10 @@ void ScreenNode::createOutput(
     if(onKey)
       onKey(k, t);
   });
+  QObject::connect(m_window.get(), &Window::keyRelease, [this](int k, const QString& t) {
+    if(onKeyRelease)
+      onKeyRelease(k, t);
+  });
   m_window->onUpdate = std::move(onUpdate);
   m_window->onWindowReady = [this, graphicsApi, onReady = std::move(onReady)] {
     m_window->state = createRenderState(*m_window, graphicsApi);
@@ -560,7 +580,7 @@ public:
 
   QShader m_vertexS, m_fragmentS;
 
-  std::vector<score::gfx::Sampler> m_samplers;
+  std::array<score::gfx::Sampler, 1> m_samplers;
 
   score::gfx::Pipeline m_p;
 
@@ -609,6 +629,7 @@ public:
     std::tie(m_vertexS, m_fragmentS)
         = score::gfx::makeShaders(renderer.state, mesh.defaultVertexShader(), gl_filter);
 
+    m_samplers = {};
     // Put the input texture, where all the input nodes are rendering, in a sampler.
     {
       auto sampler = renderer.state.rhi->newSampler(
@@ -618,7 +639,7 @@ public:
       sampler->setName("FullScreenImageNode::sampler");
       sampler->create();
 
-      m_samplers.push_back({sampler, this->m_inputTarget.texture});
+      m_samplers[0] = {sampler, this->m_inputTarget.texture};
     }
 
     m_renderTarget.renderTarget = node().m_swapChain->currentFrameRenderTarget();
@@ -665,7 +686,7 @@ public:
     {
       delete s.sampler;
     }
-    m_samplers.clear();
+    m_samplers = {};
     m_renderTarget.release();
   }
 };
