@@ -29,7 +29,7 @@ struct TexgenNode : NodeModel
   {
     v_texcoord = texcoord;
     gl_Position = renderer.clipSpaceCorrMatrix * vec4(position.xy, 0.0, 1.);
-#if defined(QSHADER_HLSL) || defined(QSHADER_MSL)
+#if !(defined(QSHADER_SPIRV) || defined(QSHADER_HLSL) || defined(QSHADER_MSL))
   gl_Position.y = - gl_Position.y;
 #endif
   }
@@ -76,11 +76,11 @@ struct TexgenNode : NodeModel
       std::tie(m_vertexS, m_fragmentS)
           = score::gfx::makeShaders(renderer.state, vertex, filter);
 
-      auto& n = static_cast<const TexgenNode&>(this->node);
       auto& rhi = *renderer.state.rhi;
       {
-        texture
-            = rhi.newTexture(QRhiTexture::RGBA8, n.image.size(), 1, QRhiTexture::Flag{});
+        vec.resize(640 * 480 * 4);
+        texture = rhi.newTexture(
+            QRhiTexture::RGBA8, QSize(640, 480), 1, QRhiTexture::Flag{});
 
         texture->create();
       }
@@ -100,12 +100,42 @@ struct TexgenNode : NodeModel
         RenderList& renderer, QRhiResourceUpdateBatch& res,
         score::gfx::Edge* edge) override
     {
+      if(!edge)
+        return;
+
+      auto& n = const_cast<TexgenNode&>(static_cast<const TexgenNode&>(this->node));
       defaultUBOUpdate(renderer, res);
-      auto& n = static_cast<const TexgenNode&>(this->node);
+      auto sz = renderer.renderSize(edge);
+      auto bytes = sz.width() * sz.height() * 4;
+      if(bytes != vec.size())
+      {
+        vec.resize(bytes, boost::container::default_init);
+
+        QRhiTexture* oldtex = texture;
+        QRhiTexture* newtex = renderer.state.rhi->newTexture(
+            QRhiTexture::RGBA8, sz, 1, QRhiTexture::Flag{});
+        newtex->create();
+        for(auto& [edge, pass] : this->m_p)
+          if(pass.srb)
+            score::gfx::replaceTexture(*pass.srb, m_samplers[0].sampler, newtex);
+        texture = newtex;
+
+        if(oldtex && oldtex != &renderer.emptyTexture())
+        {
+          oldtex->deleteLater();
+        }
+      }
+
       if(func_t f = n.function.load())
       {
-        f(const_cast<uchar*>(n.image.bits()), n.image.width(), n.image.height(), t++);
-        res.uploadTexture(texture, n.image);
+        f(vec.data(), sz.width(), sz.height(), t++);
+
+        QRhiTextureSubresourceUploadDescription subdesc{
+            QByteArray::fromRawData((const char*)vec.data(), vec.size())};
+        QRhiTextureUploadEntry entry{0, 0, subdesc};
+        QRhiTextureUploadDescription desc{entry};
+
+        res.uploadTexture(texture, desc);
       }
     }
 
@@ -118,14 +148,10 @@ struct TexgenNode : NodeModel
     }
 
     int t = 0;
+    boost::container::vector<unsigned char> vec;
   };
 
-  QImage image;
-  TexgenNode()
-  {
-    image = QImage{QSize(640, 480), QImage::Format_ARGB32_Premultiplied};
-    output.push_back(new Port{this, {}, Types::Image, {}});
-  }
+  TexgenNode() { output.push_back(new Port{this, {}, Types::Image, {}}); }
   virtual ~TexgenNode()
   {
     m_materialData.release();
