@@ -10,7 +10,8 @@ class SCORE_PLUGIN_GFX_EXPORT InvertYRenderer final
 {
 public:
   explicit InvertYRenderer(
-      score::gfx::TextureRenderTarget rt, QRhiReadbackResult& readback);
+      const score::gfx::Node& n, score::gfx::TextureRenderTarget rt,
+      QRhiReadbackResult& readback);
 
   score::gfx::TextureRenderTarget m_inputTarget;
   score::gfx::TextureRenderTarget m_renderTarget;
@@ -34,11 +35,15 @@ public:
       QRhiResourceUpdateBatch*& res) override;
 
   void init(score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res) override;
-  void update(score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res) override;
+  void update(
+      score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res,
+      score::gfx::Edge* edge) override;
   void release(score::gfx::RenderList&) override;
 
+  void updateReadback(QRhiReadbackResult& rb) { m_readback = &rb; }
+
 private:
-  QRhiReadbackResult& m_readback;
+  QRhiReadbackResult* m_readback{};
 };
 
 }
