@@ -445,6 +445,7 @@ AVFormatContext_ptr open_audio(const QString& path)
 }
 
 std::optional<AudioInfo> AudioDecoder::do_probe(const QString& path)
+try
 {
 #if SCORE_HAS_LIBAV
   auto fmt_ctx = open_audio(path);
@@ -484,6 +485,10 @@ std::optional<AudioInfo> AudioDecoder::do_probe(const QString& path)
 #endif
   return {};
 }
+catch(...)
+{
+  return {};
+}
 
 QHash<QString, AudioInfo>& AudioDecoder::database()
 {
