@@ -5,6 +5,7 @@
 #include "ZoomPolicy.hpp"
 
 #include <Process/DocumentPlugin.hpp>
+#include <Process/Drop/ProcessDropHandler.hpp>
 #include <Process/LayerPresenter.hpp>
 #include <Process/LayerView.hpp>
 #include <Process/Process.hpp>
@@ -12,6 +13,8 @@
 #include <Process/Style/ScenarioStyle.hpp>
 #include <Process/TimeValue.hpp>
 
+#include <Scenario/Application/Drops/DropOnCable.hpp>
+#include <Scenario/Application/Drops/ScenarioDropHandler.hpp>
 #include <Scenario/Application/ScenarioActions.hpp>
 #include <Scenario/Application/ScenarioApplicationPlugin.hpp>
 #include <Scenario/Commands/CommandAPI.hpp>
@@ -208,9 +211,43 @@ ScenarioDocumentPresenter::ScenarioDocumentPresenter(
   }
 
   setDisplayedInterval(&model().baseInterval());
+  QTimer::singleShot(0, [this] { view().minimap().zoom(0.0); });
 
+  // Drop on cables
+  connect(
+      &m_dataflow, &Process::DataflowManager::cableItemCreated, this,
+      &ScenarioDocumentPresenter::on_cableItemCreated);
   model().cables.mutable_added.connect<&ScenarioDocumentPresenter::on_cableAdded>(*this);
   model().cables.removing.connect<&ScenarioDocumentPresenter::on_cableRemoving>(*this);
+
+  // Need to reset cables & ports in case of drop
+  // due to https://bugreports.qt.io/browse/QTBUG-140114
+  con(view().view(), &ProcessGraphicsView::dropFinished, this,
+      &ScenarioDocumentPresenter::on_dropFinished);
+}
+
+void ScenarioDocumentPresenter::on_dropFinished()
+{
+  for(auto& [model, item] : this->m_dataflow.cables())
+  {
+    if(!item)
+      continue;
+    item->resetDrop();
+  }
+  for(auto& [model, item] : this->m_dataflow.ports())
+  {
+    if(!item)
+      continue;
+    item->resetDrop();
+    QGraphicsItem* parent = item->parentItem();
+    Process::NodeItem* node{};
+    while(parent && !(node = qgraphicsitem_cast<Process::NodeItem*>(parent)))
+    {
+      parent = parent->parentItem();
+    }
+    if(node)
+      node->resetDrop();
+  }
 }
 
 void ScenarioDocumentPresenter::recenterNodal()
@@ -358,6 +395,14 @@ void ScenarioDocumentPresenter::setZoomRatio(ZoomRatio newRatio)
   }
 }
 
+void ScenarioDocumentPresenter::on_dropInEmptyFullView(
+    QPoint viewPos, const QMimeData* data)
+{
+  auto& ctx = m_context;
+  ctx.app.interfaces<Scenario::IntervalDropHandlerList>().drop(
+      ctx, this->displayedInterval(), QPointF{}, *data);
+}
+
 void ScenarioDocumentPresenter::on_horizontalZoom(QPointF zoom, QPointF scenePoint)
 {
   auto& map = view().minimap();
@@ -639,6 +684,24 @@ void ScenarioDocumentPresenter::on_addPresetFromLibrary(const Process::Preset& d
   ossia::visit(vis, m_centralDisplay);
 }
 
+void ScenarioDocumentPresenter::on_cableItemCreated(Dataflow::CableItem* item)
+{
+  connect(
+      item, &Dataflow::CableItem::dropReceived, this,
+      &ScenarioDocumentPresenter::on_dropOnCable);
+}
+
+void ScenarioDocumentPresenter::on_dropOnCable(const QPointF& pos, const QMimeData& mime)
+{
+  auto item = qobject_cast<Dataflow::CableItem*>(QObject::sender());
+  if(!item)
+    return;
+
+  auto dropOnCable = new Scenario::DropOnCable{*item, model(), m_context};
+  dropOnCable->drop(pos, mime);
+  dropOnCable->deleteLater();
+}
+
 void ScenarioDocumentPresenter::restoreZoom()
 {
   if(auto z = displayedInterval().zoom(); z > 0)
