@@ -5,14 +5,21 @@
 #include <score/graphics/GraphicsItem.hpp>
 #include <score/model/Identifier.hpp>
 
+#include <nano_observer.hpp>
 #include <score_plugin_scenario_export.h>
 
 #include <verdigris>
 
+namespace Process
+{
+class ProcessModel;
+}
 namespace Scenario
 {
 class StateModel;
-class SCORE_PLUGIN_SCENARIO_EXPORT StatePresenter final : public QObject
+class SCORE_PLUGIN_SCENARIO_EXPORT StatePresenter final
+    : public QObject
+    , public Nano::Observer
 {
   W_OBJECT(StatePresenter)
 
@@ -33,6 +40,8 @@ public:
   bool isSelected() const;
 
   void handleDrop(const QMimeData& mime);
+  void on_processAdded(const Process::ProcessModel&);
+  void on_processRemoved(const Process::ProcessModel&);
 
 public:
   void pressed(const QPointF& arg_1)
